# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Location Referencing Tools"""
__all__ = ['AppendEvents', 'AppendRoutes', 'ApplyEventBehaviors',
           'ConfigureLookupTable', 'ConfigureUtilityNetworkFeatureClass',
           'CreateLRS', 'CreateLRSEvent', 'CreateLRSEventFromExistingDataset',
           'CreateLRSFromExistingDataset', 'CreateLRSIntersection',
           'CreateLRSIntersectionFromExistingDataset', 'CreateLRSNetwork',
           'CreateLRSNetworkFromExistingDataset', 'DeleteRoutes',
           'DeriveEventMeasures', 'DisableDerivedMeasureFields',
           'DisableReferentFields', 'EnableDerivedMeasureFields',
           'EnableReferentFields', 'GenerateCalibrationPoints',
           'GenerateEvents', 'GenerateIntersections', 'GenerateRoutes',
           'ModifyEventBehaviorRules', 'ModifyLRS', 'ModifyLRSEvent',
           'ModifyLRSIntersection', 'ModifyLRSNetwork',
           'ModifyNetworkCalibrationRules', 'ModifyRouteIdPadding',
           'OverlayEvents', 'RemoveLRSEntity', 'RemoveOverlappingCenterlines',
           'TranslateEventMeasures', 'UpdateMeasuresFromLRS']
__alias__ = 'locref'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('AppendEvents_locref', None)
def AppendEvents(in_dataset=None, in_target_event=None, field_mapping=None, load_type=None, generate_event_ids=None, generate_shapes=None):
    """AppendEvents_locref(in_dataset, in_target_event, field_mapping, {load_type}, {generate_event_ids}, {generate_shapes})

        Appends event records from a table, layer, or feature class to an
        existing ArcGIS Location Referencing event feature class.When the
        target layer is a feature service layer, the validation
        results for this tool are written to a file in the ArcGIS Server
        directory. By default, this file will be automatically cleaned up
        after 10 minutes, which may not be enough time to process all of the
        validations and write them to your workstation that is running ArcGIS
        Pro. For larger data loads, it is recommended that you adjust the
        maximum file age to at least one hour. You can edit a server directory
        in Manager to adjust this setting.

     INPUTS:
      in_dataset (Table View):
          The source event records to append.
      in_target_event (Feature Layer):
          The Location Referencing event layer or feature class into which the
          source event records will be appended.
      field_mapping (Field Mappings):
          Controls how the attribute information in fields of the in_dataset is
          transferred to the in_target_event.Because the data of in_dataset is
          appended into an existing event that
          has a predefined schema (field definitions), fields cannot be added or
          removed from the target dataset. While you can set merge rules for
          each output field, the tool ignores those rules.The ArcPy
          FieldMappings class can be used to define this parameter.
      load_type {String}:
          Specifies how appended events with measure or temporality overlaps
          with identical Event IDs as Target Event records will be loaded into
          the event feature class.

          * ADD-Appends the Input Event records to the Target Event. No changes
          are made to Target Event records.

          * RETIRE_OVERLAPS-Appends the Input Event records to the Target Event
          and retires any records in the Target Event with measure or
          temporality overlaps as the appended events. If the appended event
          eclipses the Target Event, the Target Event will be deleted. This
          option should only be used for linear events.

          * RETIRE_BY_EVENT_ID-Appends the Input Event records to the Target
          Event and retires any records in the Target Event with the same Event
          ID and temporality overlaps as the appended events. If the appended
          event eclipses a Target Event with the same Event ID, the Target Event
          will be deleted.

          * REPLACE_BY_EVENT_ID-Appends the Input Event records to the Target
          Event and deletes any records in the Target Event with the same Event
          ID as the appended events.
      generate_event_ids {Boolean}:
          Specifies whether event IDs will be generated for in_dataset records
          being appended. Generation of event IDs will only be applied to
          in_dataset records with a Null value for the Event ID field.

          * GENERATE_EVENT_IDS-Generates event IDs for the in_dataset records
          being appended.

          * NO_GENERATE_EVENT_IDS-Does not generate event IDs for the in_dataset
          records being appended. This is the default.
      generate_shapes {Boolean}:
          Specifies whether the shapes of the records being appended will be
          regenerated. This parameter is only enabled when the in_dataset is a
          feature layer or feature class.

          * GENERATE_SHAPES-The shapes of the input event features will be
          regenerated. This is the default.

          * NO_SHAPES-The shapes of the input event features will not be
          regenerated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendEvents_locref(*gp_fixargs((in_dataset, in_target_event, field_mapping, load_type, generate_event_ids, generate_shapes), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AppendRoutes_locref', None)
def AppendRoutes(source_routes=None, in_lrs_network=None, route_id_field=None, route_name_field=None, from_date_field=None, to_date_field=None, line_id_field=None, line_name_field=None, line_order_field=None, field_map=None, load_type=None):
    """AppendRoutes_locref(source_routes, in_lrs_network, route_id_field, {route_name_field}, {from_date_field}, {to_date_field}, {line_id_field}, {line_name_field}, {line_order_field}, {field_map}, {load_type})

        Appends routes from an input polyline into an LRS Network.When the
        target layer is a feature service layer, the validation
        results for this tool are written to the ArcGIS Server directory. This
        file is automatically cleaned up in 10 minutes by default, which may
        not be enough time to process all of the validations and write them to
        your workstation running ArcGIS Pro. For larger data loads, it is
        recommended that you adjust the maximum file age to at least one hour.

     INPUTS:
      source_routes (Feature Layer):
          The input from which the routes will be derived. The input can be a
          polyline feature class, shapefile, feature service, or LRS Network
          feature class.
      in_lrs_network (Feature Layer):
          The target LRS Network into which the routes will be loaded.
      route_id_field (Field):
          The field in the input polyline feature class that will be mapped to
          the LRS Network route ID. The field type must match the RouteID field
          type of the target LRS Network and must be either a string or GUID
          field type. If it is a text field, the field length must be shorter
          than or equal to the length of the target RouteID field.
      route_name_field {Field}:
          The field in the input polyline feature class that will be mapped as
          the LRS Network route name. The field must be a string field, and the
          field length must be shorter than or equal to the length of the target
          route name field.
      from_date_field {Field}:
          A date field in the input polyline feature class that will be mapped
          as the From Date Field in the LRS Network . If the field is not
          mapped, a null value representing the beginning of time will be
          provided for all appended routes.
      to_date_field {Field}:
          A date field in the input polyline feature class that will be mapped
          as the To date in the LRS Network. If a To date field is not mapped, a
          null value representing the end of time will be provided for all
          appended routes.
      line_id_field {Field}:
          The field in the input polyline feature class that will be mapped as
          the LRS Network line ID. This parameter is only used if the target is
          an LRS line network. The field type must match the RouteID field type
          of the centerline sequence table and must be either a string of
          exactly 38 characters or a GUID field type.
      line_name_field {Field}:
          The string field in the input polyline feature class that will be
          mapped as the LRS Network line name. This parameter is only used if
          the target is an LRS line network.
      line_order_field {Field}:
          The long integer field in the input polyline feature class that will
          be mapped as the LRS Network line order. This parameter is only used
          if the target is an LRS line network.Learn more about line networks
          and line order in Pipeline Referencing
          or line networks and line order in Roads and Highways.
      field_map {Field Mappings}:
          Controls how attribute information in the source route fields is
          transferred to the input LRS Network. Fields cannot be added to or
          removed from the target LRS Network because the data of the source
          routes is appended into an existing LRS Network that has a predefined
          schema (field definitions). While you can set merge rules for each
          output field, the tool will ignore those rules. The ArcPy
          FieldMappings class can be used to define this parameter.
      load_type {String}:
          Specifies how appended routes with measure or temporality overlaps
          with identical route IDs as Target Network records are loaded into the
          network feature class.

          * ADD-The appended routes are loaded into the target LRS Network. If
          any route ID in the source routes already exists in the target LRS
          Network with the same temporality, it will be written to the output
          log as a duplicate route and must be corrected or filtered out before
          completing the loading process. This is the default.

          * RETIRE_BY_ROUTE_ID-The appended routes are loaded into the target
          LRS Network and any routes in the target LRS Network that have the
          same route ID and temporality overlap as the appended routes are
          retired. If the appended route eclipses a target route with the same
          route ID, the target route is deleted.

          * REPLACE_BY_ROUTE_ID-The appended routes are loaded into the target
          LRS Network and any routes in the target LRS Network with the same
          route ID as the appended routes are deleted."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendRoutes_locref(*gp_fixargs((source_routes, in_lrs_network, route_id_field, route_name_field, from_date_field, to_date_field, line_id_field, line_name_field, line_order_field, field_map, load_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyEventBehaviors_locref', None)
def ApplyEventBehaviors(in_route_features=None):
    """ApplyEventBehaviors_locref(in_route_features)

        Updates the event locations for all event feature classes registered
        with the input network based on the route edit performed.The events
        get updated as per the configured event behavior.To learn more about
        event behavior and configuring event behavior, see
        event behavior in ArcGIS Pipeline Referencing or event behavior in
        ArcGIS Roads and Highways.

     INPUTS:
      in_route_features (Feature Layer):
          The LRS Network for which event locations will be updated. This must
          be a feature layer registered as a network with the LRS."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyEventBehaviors_locref(*gp_fixargs((in_route_features,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteRoutes_locref', None)
def DeleteRoutes(in_route_features=None, delete_associated_calibration_points=None, delete_associated_events=None, delete_associated_centerlines=None):
    """DeleteRoutes_locref(in_route_features, {delete_associated_calibration_points}, {delete_associated_events}, {delete_associated_centerlines})

        Deletes routes and associated data elements from the LRS Network.

     INPUTS:
      in_route_features (Feature Layer):
          The route feature class registered with the network.
      delete_associated_calibration_points {Boolean}:
          Specifies whether calibration points associated with the deleted
          routes will be deleted.

          * DELETE_CALIBRATION_POINTS-Calibration points associated with the
          routes will be deleted.

          * NO_DELETE_CALIBRATION_POINTS-Calibration points associated with the
          routes will not be deleted. This is the default.
      delete_associated_events {Boolean}:
          Specifies whether events associated with the deleted routes will be
          deleted.

          * DELETE_EVENTS-Events associated with the routes will be deleted.

          * NO_DELETE_EVENTS-Events associated with the routes will not be
          deleted. This is the default.
      delete_associated_centerlines {Boolean}:
          Specifies whether centerlines that are exclusively associated with the
          deleted routes will be deleted.

          * DELETE_CENTERLINES-Centerlines exclusively associated with the
          selected routes will be deleted. If centerlines are shared between
          networks, those common centerlines will not be deleted.

          * NO_DELETE_CENTERLINES-Centerlines will not be deleted. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteRoutes_locref(*gp_fixargs((in_route_features, delete_associated_calibration_points, delete_associated_events, delete_associated_centerlines), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeriveEventMeasures_locref', None)
def DeriveEventMeasures(in_route_features=None, update_all_events=None, event_layers=None):
    """DeriveEventMeasures_locref(in_route_features, {update_all_events}, {event_layers;event_layers...})

        Populates and updates the DerivedRouteID field and measure values on
        point and line events with those fields configured and enabled.

     INPUTS:
      in_route_features (Feature Layer):
          The LRS Network containing the events with DerivedRouteID and measure
          fields configured.
      update_all_events {Boolean}:
          Determines whether all event feature classes in the network will be
          updated.

          * UPDATE_ALL-Updates all events in the network selected in
          in_route_features. This is the default.

          * UPDATE_SOME-Does not update all events in the network selected in
          the in_route_features. Allows the user to select individual event
          layers in the event_layers parameter below.
      event_layers {Feature Layer}:
          The event layers that will have DerivedRouteID and measure fields
          updated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeriveEventMeasures_locref(*gp_fixargs((in_route_features, update_all_events, event_layers), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateCalibrationPoints_locref', None)
def GenerateCalibrationPoints(in_polyline_features=None, route_id_field=None, from_date_field=None, to_date_field=None, in_calibration_point_feature_class=None, lrs_network=None, calibration_direction=None, calibration_method=None):
    """GenerateCalibrationPoints_locref(in_polyline_features, route_id_field, from_date_field, to_date_field, in_calibration_point_feature_class, lrs_network, {calibration_direction}, {calibration_method})

        Generates calibration points for any route shape provided, including
        complex shapes such as self-closing, self-intersecting, and branched
        routes.

     INPUTS:
      in_polyline_features (Feature Layer):
          The features that will be used as the source to calculate the measure
          values for calibration points.
      route_id_field (Field):
          The field containing values that uniquely identify each route. The
          field type must match the Route ID field in the calibration point
          feature class.
      from_date_field (Field):
          The field containing the From Date values of a route.
      to_date_field (Field):
          The field containing the To Date values of a route.
      in_calibration_point_feature_class (Feature Layer):
          The existing calibration point feature class to which new features
          will be added.
      lrs_network (String):
          The LRS Network for which the measure values will be generated in the
          calibration points feature class.
      calibration_direction {String}:
          Specifies the direction of increasing calibration on a route when
          creating new calibration points.

          * DIGITIZED_DIRECTION-The direction of digitization of the Input
          Polyline Features determines the direction of calibration for the
          route. This is the default.

          * MEASURE_DIRECTION-The direction of increasing m-values of the Input
          Polyline Features determines the direction of calibration for the
          route. If Input Polyline Features does not include m-values, the
          digitized direction will be used instead.
      calibration_method {String}:
          The method used to determine the measures on a route when creating
          calibration points.

          * GEOMETRY_LENGTH-Only geometry length is supported as the calibration
          method."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateCalibrationPoints_locref(*gp_fixargs((in_polyline_features, route_id_field, from_date_field, to_date_field, in_calibration_point_feature_class, lrs_network, calibration_direction, calibration_method), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateEvents_locref', None)
def GenerateEvents(in_event_layer=None):
    """GenerateEvents_locref(in_event_layer)

        Re-creates shapes for event features registered with an LRS Network.

     INPUTS:
      in_event_layer (Feature Layer):
          The event for which shapes will be regenerated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateEvents_locref(*gp_fixargs((in_event_layer,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateIntersections_locref', None)
def GenerateIntersections(in_intersection_feature_class=None, in_network_layer=None, start_date=None, edited_by_current_user=None):
    """GenerateIntersections_locref(in_intersection_feature_class, {in_network_layer}, {start_date}, {edited_by_current_user})

        Generates new intersections and updates existing intersections.Learn
        more about generating and updating intersections in Pipeline
        Referencing or generating and updating intersections in Roads and
        Highways.

     INPUTS:
      in_intersection_feature_class (Feature Layer):
          The input LRS intersection feature class or layer.
      in_network_layer {Feature Layer}:
          The input LRS Network feature class or layer.
      start_date {Date}:
          Filters routes that have been edited after a certain date so that
          intersections can be generated.
      edited_by_current_user {Boolean}:
          Specifies whether intersections will be generated only for routes
          edited and locked by the current user.

          * CURRENT_USER-Intersections will be generated only for routes edited
          by the current user. This is the default.

          * ALL_USERS-Intersections will be generated for all edited routes."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateIntersections_locref(*gp_fixargs((in_intersection_feature_class, in_network_layer, start_date, edited_by_current_user), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateRoutes_locref', None)
def GenerateRoutes(in_route_features=None, record_calibration_changes=None):
    """GenerateRoutes_locref(in_route_features, {record_calibration_changes})

        Re-creates shapes and applies calibration changes for route features
        in an LRS Network.Additionally, the tool can determine calibration
        changes on routes so
        event behaviors can be processed. These calibration changes can be due
        to adding, editing, or deleting calibration points outside the
        Location Referencing tools in ArcGIS Pro.

     INPUTS:
      in_route_features (Feature Layer):
          The LRS Network for which route shapes will be regenerated and
          calibration changes will be applied.
      record_calibration_changes {Boolean}:
          Specifies whether event behaviors will be applied.

          * RECORD_CALIBRATION_CHANGES-Any calibration points created, modified,
          or deleted outside the Location Referencing tools will be applied to
          the routes in the network, and event behaviors will be applied the
          next time Apply Event Behaviors is run.

          * NO_RECORD_CALIBRATION_CHANGES-Calibration changes will be applied to
          the routes in the LRS Network, but no event behaviors will be applied.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateRoutes_locref(*gp_fixargs((in_route_features, record_calibration_changes), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OverlayEvents_locref', None)
def OverlayEvents(in_route_features=None, event_layers=None, output_dataset=None, include_geometry=None, network_fields=None):
    """OverlayEvents_locref(in_route_features, event_layers;event_layers..., output_dataset, {include_geometry}, {network_fields;network_fields...})

        Overlays one or more linear event feature layers onto a target network
        and outputs a feature class or table that represents the dynamic
        segmentation of the inputs.

     INPUTS:
      in_route_features (Feature Layer):
          The target network onto which the event layers will be dynamically
          segmented.
      event_layers (Feature Layer):
          The event layers to be dynamically segmented together onto a target
          network.
      include_geometry {Boolean}:
          Specifies whether the output_dataset will include event geometry.

          * EXCLUDE_GEOMETRY-The output_dataset will not include event geometry.
          Event records will be stored as a table. This is the default.

          * INCLUDE_GEOMETRY-The output_dataset will include event geometry.
          Event records will be stored as a feature class.
      network_fields {Field}:
          Fields from the network layer that will be included in the output.

     OUTPUTS:
      output_dataset (Table):
          The table or feature class to be created, containing the output event
          records."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OverlayEvents_locref(*gp_fixargs((in_route_features, event_layers, output_dataset, include_geometry, network_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveOverlappingCenterlines_locref', None)
def RemoveOverlappingCenterlines(in_centerline_features=None):
    """RemoveOverlappingCenterlines_locref(in_centerline_features)

        Removes overlapping centerline sections to ensure that there is one
        common centerline in cases where centerline geometry overlaps.The
        ArcGIS Location Referencing minimum schema models route
        concurrencies by having routes share the same centerline associations
        in the centerline sequence table. Running this tool may result in
        centerline changes, such as centerline splitting or deletion of
        duplicated centerline features. It may also update centerline sequence
        table records so that routes share centerlines. Overlapping
        centerlines can result when any of the following
        occur:

        * A network with concurrent routes is loaded

        * An additional network is loaded

        * Ad-hoc user centerline editing
        While the Remove Overlapping Centerlines tool can be run any time
        after a LRS Network is created and data is loaded, consider running it
        only after you've finished creating all LRS Networks and have loaded
        all data in your LRS. If additional columns are modeled on the
        centerlines, some centerline attributes may be lost when the tool is
        run.

     INPUTS:
      in_centerline_features (Feature Layer):
          An input layer or feature class representing an LRS centerline."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveOverlappingCenterlines_locref(*gp_fixargs((in_centerline_features,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TranslateEventMeasures_locref', None)
def TranslateEventMeasures(in_source_event=None, in_target_route_features=None, out_target_event=None, in_concurrent_route_matching=None):
    """TranslateEventMeasures_locref(in_source_event, in_target_route_features, out_target_event, {in_concurrent_route_matching})

        Translates the measures (m-values) of a point or line event layer from
        one linear referencing method (LRM) to another.A use case for this
        tool would be to translate event data from a mile-
        based network to a kilometer-based network.In addition to measures,
        the route associations of the event features
        may also be different between the two LRMs. The output of this tool is
        a feature class with the correct measures and route associations of
        the target LRS Network.

     INPUTS:
      in_source_event (Feature Layer):
          The input event layer to be translated.
      in_target_route_features (Feature Layer):
          The target LRS Network against which the input events will be
          translated.
      in_concurrent_route_matching {String}:
          Specifies the method used to determine which route to translate the
          event against when concurrent routes exist in the target LRS Network.
          This parameter is only applied when the location of the event
          translation on the target LRS Network has concurrent routes (routes
          that share a location).

          * ANY-The input event layer is translated against the first of two or
          more concurrent routes found in the target LRS Network.

          * ROUTE_ID-The Route ID of the source event is compared to the Route
          IDs of concurrent routes in the target LRS Network. The source event
          will translate based on Route ID matches in the source event and
          target network. The Route IDs of the input event and target LRS
          Network must be an exact match for this method to correctly translate
          the event. The input event layer must also be a registered LRS event
          to use this method.

          * ALL-The input event is translated against all the concurrent routes
          at that location in the target LRS Network.

     OUTPUTS:
      out_target_event (Feature Class):
          The output feature class that will contain the translated event
          features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TranslateEventMeasures_locref(*gp_fixargs((in_source_event, in_target_route_features, out_target_event, in_concurrent_route_matching), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateMeasuresFromLRS_locref', None)
def UpdateMeasuresFromLRS(lrs_network=None, lrs_date=None, in_features=None, route_id_field=None, from_measure_field=None, to_measure_field=None):
    """UpdateMeasuresFromLRS_locref(lrs_network, lrs_date, in_features, route_id_field, from_measure_field, {to_measure_field})

        Populates or updates the measures and route ID on Utility Network (UN)
        features such as pipes, devices, and junctions or on features in other
        non-UN or non-LRS feature classes.This tool finds appropriate routes
        from the LRS Network parameter,
        gets the measures from that route, and populates or updates the
        measure and route attributes for the features in the non-LRS feature
        class.The ArcGIS Pipeline Referencing Server extension is required to
        use
        this tool.

     INPUTS:
      lrs_network (Feature Layer):
          The feature service layer that contains the routes, route IDs, and
          measures.
      lrs_date (Date):
          The date used to define the temporal view of the network for
          collecting the route and measure values.
      in_features (Feature Layer):
          The layer that includes route ID and measure fields that will be
          updated based on feature geometry relative to routes in the LRS
          Network parameter.
      route_id_field (Field):
          The field in the Input Features layer that contains the route ID
          value.
      from_measure_field (Field):
          The field in the Input Features layer that contains the from measure
          value for polyline features.
      to_measure_field {Field}:
          The field in the Input Features layer that contains the measure value
          for point features or the to measure value for polyline features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateMeasuresFromLRS_locref(*gp_fixargs((lrs_network, lrs_date, in_features, route_id_field, from_measure_field, to_measure_field), True)))
        return retval
    except Exception as e:
        raise e


# Configuration toolset
@gptooldoc('ConfigureUtilityNetworkFeatureClass_locref', None)
def ConfigureUtilityNetworkFeatureClass(in_feature_class=None, route_id_field=None, from_measure_field=None, to_measure_field=None):
    """ConfigureUtilityNetworkFeatureClass_locref(in_feature_class, route_id_field, from_measure_field, to_measure_field)

        Configures a Utility Network pipeline feature class for use with a
        linear referencing system (LRS).After configuration, the Route ID
        Field parameter and the measure
        columns can be updated as needed.

     INPUTS:
      in_feature_class (Feature Layer):
          The input Utility Network feature that is also the LRS centerline
          feature.
      route_id_field (Field):
          The field in the feature class that will be mapped as the LRS Network
          Route ID.
      from_measure_field (Field):
          The From measure field of the centerline feature class.
      to_measure_field (Field):
          The To measure field of the centerline feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConfigureUtilityNetworkFeatureClass_locref(*gp_fixargs((in_feature_class, route_id_field, from_measure_field, to_measure_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveLRSEntity_locref', None)
def RemoveLRSEntity(in_workspace=None, lrs_entity_type=None, lrs_entity_name=None):
    """RemoveLRSEntity_locref(in_workspace, lrs_entity_type, lrs_entity_name)

        Removes a linear referencing system (LRS) entity from an input
        geodatabase workspace.

     INPUTS:
      in_workspace (Workspace):
          The input geodatabase workspace that contains the LRS entity that will
          be removed.
      lrs_entity_type (String):
          Specifies the type of LRS entity that will be removed from the input
          geodatabase workspace.

          * LRS-An LRS and its dependent LRS Networks, as well as the LRS
          events, and LRS intersections registered to those LRS Networks, will
          be removed.

          * NETWORK-An LRS Network and the LRS events and LRS intersections
          registered to that LRS Network will be removed.

          * EVENT-An LRS event will be removed.

          * INTERSECTION-An LRS intersection will be removed.

          * UN_FEATURE_CLASS-A utility network feature class will be removed.
      lrs_entity_name (String):
          The name of the LRS entity that will be removed from the input
          geodatabase workspace. The underlying feature classes and tables of
          the LRS entity will not be deleted."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveLRSEntity_locref(*gp_fixargs((in_workspace, lrs_entity_type, lrs_entity_name), True)))
        return retval
    except Exception as e:
        raise e


# Configuration\LRS toolset
@gptooldoc('CreateLRS_locref', None)
def CreateLRS(in_workspace=None, lrs_name=None, centerline_feature_class_name=None, calibration_point_feature_class_name=None, redline_feature_class_name=None, centerline_sequence_table_name=None, spatial_reference=None, xy_tolerance=None, z_tolerance=None, xy_resolution=None, z_resolution=None):
    """CreateLRS_locref(in_workspace, lrs_name, centerline_feature_class_name, calibration_point_feature_class_name, redline_feature_class_name, centerline_sequence_table_name, spatial_reference, {xy_tolerance}, {z_tolerance}, {xy_resolution}, {z_resolution})

        Creates a linear referencing system (LRS) and minimum schema items in
        a specified workspace.

     INPUTS:
      in_workspace (Workspace / Feature Dataset):
          The file or multipurpose geodatabase where the LRS and minimum schema
          will be created.
      lrs_name (String):
          The name of the output LRS.
      centerline_feature_class_name (String):
          Name of the output centerline feature class.
      calibration_point_feature_class_name (String):
          Name of the output calibration point feature class.
      redline_feature_class_name (String):
          Name of the output redline feature class.
      centerline_sequence_table_name (String):
          Name of the output centerline sequence table.
      spatial_reference (Spatial Reference):
          The spatial reference for the output feature classes. When executing
          from a Python script, you can use the Well Known ID (WKID) for the
          spatial reference.
      xy_tolerance {Linear Unit}:
          The xy-tolerance of the output feature classes.
      z_tolerance {Linear Unit}:
          The z-tolerance of the output feature classes.
      xy_resolution {Linear Unit}:
          The xy-resolution of the output feature classes.
      z_resolution {Linear Unit}:
          The z-resolution of the output feature classes."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRS_locref(*gp_fixargs((in_workspace, lrs_name, centerline_feature_class_name, calibration_point_feature_class_name, redline_feature_class_name, centerline_sequence_table_name, spatial_reference, xy_tolerance, z_tolerance, xy_resolution, z_resolution), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateLRSFromExistingDataset_locref', None)
def CreateLRSFromExistingDataset(lrs_name=None, centerline_feature_class=None, centerline_centerline_id_field=None, centerline_sequence_table=None, centerline_sequence_centerline_id_field=None, centerline_sequence_route_id_field=None, centerline_sequence_from_date_field=None, centerline_sequence_to_date_field=None, centerline_sequence_network_id_field=None, calibration_point_feature_class=None, calibration_point_measure_field=None, calibration_point_from_date_field=None, calibration_point_to_date_field=None, calibration_point_route_id_field=None, calibration_point_network_id_field=None, redline_feature_class=None, redline_from_measure_field=None, redline_to_measure_field=None, redline_route_id_field=None, redline_route_name_field=None, redline_effective_date_field=None, redline_activity_type_field=None, redline_network_id_field=None):
    """CreateLRSFromExistingDataset_locref(lrs_name, centerline_feature_class, centerline_centerline_id_field, centerline_sequence_table, centerline_sequence_centerline_id_field, centerline_sequence_route_id_field, centerline_sequence_from_date_field, centerline_sequence_to_date_field, centerline_sequence_network_id_field, calibration_point_feature_class, calibration_point_measure_field, calibration_point_from_date_field, calibration_point_to_date_field, calibration_point_route_id_field, calibration_point_network_id_field, redline_feature_class, redline_from_measure_field, redline_to_measure_field, redline_route_id_field, redline_route_name_field, redline_effective_date_field, redline_activity_type_field, redline_network_id_field)

        Creates a linear referencing system (LRS) in the specified workspace
        using existing datasets.

     INPUTS:
      lrs_name (String):
          The name of the LRS to create. The name for the LRS cannot already
          exist in the geodatabase.
      centerline_feature_class (Feature Layer):
          The feature class to be used as the centerline in the LRS.
      centerline_centerline_id_field (Field):
          The GUID field containing the centerline ID. The field type must match
          the centerlineID field type in the centerline sequence table.
      centerline_sequence_table (Table View):
          The table to be used as the centerline sequence in the LRS.
      centerline_sequence_centerline_id_field (Field):
          The GUID field containing the centerline sequence ID. The field type
          must match the centerlineID field type and length in the centerline
          feature class.
      centerline_sequence_route_id_field (Field):
          The GUID or text field containing the centerline sequence route ID.
          The field type must match the routeID field type and length in the
          calibration point and redline feature classes.
      centerline_sequence_from_date_field (Field):
          A date field containing the centerline sequence from date.
      centerline_sequence_to_date_field (Field):
          A date field containing the centerline sequence to date.
      centerline_sequence_network_id_field (Field):
          The field containing the centerline sequence network ID. The short
          integer field type is supported.
      calibration_point_feature_class (Feature Layer):
          The feature class to be used as the calibration point in the LRS.
      calibration_point_measure_field (Field):
          The field containing the calibration point measure. The double field
          type is supported.
      calibration_point_from_date_field (Field):
          A date field containing the calibration point from date.
      calibration_point_to_date_field (Field):
          A date field containing the calibration point to date.
      calibration_point_route_id_field (Field):
          The field containing the calibration point route ID. GUID and text
          field types are supported. The field type must match the routeID field
          type and length in the centerline sequence table and Redline feature
          class.
      calibration_point_network_id_field (Field):
          The field containing the calibration point network ID. The short
          integer field type is supported.
      redline_feature_class (Feature Layer):
          The feature class to be used as the redline in the LRS.
      redline_from_measure_field (Field):
          The field containing the redline from measure. The double field type
          is supported.
      redline_to_measure_field (Field):
          The field containing the redline to measure. The double field type is
          supported.
      redline_route_id_field (Field):
          The field containing the redline route ID. GUID and text field types
          are supported. The field type must match the routeID field type and
          length in the calibration point feature class and centerline sequence
          table.
      redline_route_name_field (Field):
          A text field containing the redline route name.
      redline_effective_date_field (Field):
          A date field containing the redline effective date.
      redline_activity_type_field (Field):
          The field containing the redline activity type. The short integer
          field type is supported.
      redline_network_id_field (Field):
          The field containing the redline network ID. The short integer field
          type is supported."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSFromExistingDataset_locref(*gp_fixargs((lrs_name, centerline_feature_class, centerline_centerline_id_field, centerline_sequence_table, centerline_sequence_centerline_id_field, centerline_sequence_route_id_field, centerline_sequence_from_date_field, centerline_sequence_to_date_field, centerline_sequence_network_id_field, calibration_point_feature_class, calibration_point_measure_field, calibration_point_from_date_field, calibration_point_to_date_field, calibration_point_route_id_field, calibration_point_network_id_field, redline_feature_class, redline_from_measure_field, redline_to_measure_field, redline_route_id_field, redline_route_name_field, redline_effective_date_field, redline_activity_type_field, redline_network_id_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyLRS_locref', None)
def ModifyLRS(in_workspace=None, current_lrs_name=None, new_lrs_name=None, centerline_feature_class=None, centerline_centerline_id_field=None, centerline_sequence_table=None, centerline_sequence_centerline_id_field=None, centerline_sequence_route_id_field=None, centerline_sequence_from_date_field=None, centerline_sequence_to_date_field=None, centerline_sequence_network_id_field=None, calibration_point_feature_class=None, calibration_point_measure_field=None, calibration_point_from_date_field=None, calibration_point_to_date_field=None, calibration_point_route_id_field=None, calibration_point_network_id_field=None, redline_feature_class=None, redline_from_measure_field=None, redline_to_measure_field=None, redline_route_id_field=None, redline_route_name_field=None, redline_effective_date_field=None, redline_activity_type_field=None, redline_network_id_field=None, conflict_prevention=None):
    """ModifyLRS_locref(in_workspace, current_lrs_name, {new_lrs_name}, {centerline_feature_class}, {centerline_centerline_id_field}, {centerline_sequence_table}, {centerline_sequence_centerline_id_field}, {centerline_sequence_route_id_field}, {centerline_sequence_from_date_field}, {centerline_sequence_to_date_field}, {centerline_sequence_network_id_field}, {calibration_point_feature_class}, {calibration_point_measure_field}, {calibration_point_from_date_field}, {calibration_point_to_date_field}, {calibration_point_route_id_field}, {calibration_point_network_id_field}, {redline_feature_class}, {redline_from_measure_field}, {redline_to_measure_field}, {redline_route_id_field}, {redline_route_name_field}, {redline_effective_date_field}, {redline_activity_type_field}, {redline_network_id_field}, {conflict_prevention})

        Modifies an existing linear referencing system (LRS) in the specified
        workspace.

     INPUTS:
      in_workspace (Workspace):
          The LRS workspace.
      current_lrs_name (String):
          The name of the current LRS.
      new_lrs_name {String}:
          The new name of the current LRS.
      centerline_feature_class {Feature Layer}:
          An existing centerline feature class for the minimum schema.
      centerline_centerline_id_field {Field}:
          The name of the centerline ID field from the existing centerline
          feature class that was chosen.
      centerline_sequence_table {Table View}:
          An existing centerline sequence table for the minimum schema.
      centerline_sequence_centerline_id_field {Field}:
          The name of the centerline ID field from the existing centerline
          sequence table that was chosen.
      centerline_sequence_route_id_field {Field}:
          The name of the route ID field from the existing centerline sequence
          table that was chosen.
      centerline_sequence_from_date_field {Field}:
          The name of the from date field from the existing centerline sequence
          table that was chosen.
      centerline_sequence_to_date_field {Field}:
          The name of the to date field from the existing centerline sequence
          table that was chosen.
      centerline_sequence_network_id_field {Field}:
          The name of the network ID field from the existing centerline sequence
          table that was chosen.
      calibration_point_feature_class {Feature Layer}:
          An existing calibration point feature class for the minimum schema.
      calibration_point_measure_field {Field}:
          The name of the measure field from the existing calibration point
          feature class that was chosen.
      calibration_point_from_date_field {Field}:
          The name of the from date field from the existing calibration point
          feature class that was chosen.
      calibration_point_to_date_field {Field}:
          The name of the to date field from the existing calibration point
          feature class that was chosen.
      calibration_point_route_id_field {Field}:
          The name of the route ID field from the existing calibration point
          feature class that was chosen.
      calibration_point_network_id_field {Field}:
          The name of the network ID field from the existing calibration point
          feature class that was chosen.
      redline_feature_class {Feature Layer}:
          An existing redline feature class for the minimum schema.
      redline_from_measure_field {Field}:
          The name of the from measure field from the existing redline feature
          class that was chosen.
      redline_to_measure_field {Field}:
          The name of the to measure field from the existing redline feature
          class that was chosen.
      redline_route_id_field {Field}:
          The name of the route ID field from the existing redline feature class
          that was chosen.
      redline_route_name_field {Field}:
          The name of the route name field from the existing redline feature
          class that was chosen.
      redline_effective_date_field {Field}:
          The name of the effective date field from the existing redline feature
          class that was chosen.
      redline_activity_type_field {Field}:
          The name of the activity type field from the existing redline feature
          class that was chosen.
      redline_network_id_field {Field}:
          The name of the network ID field from the existing redline feature
          class that was chosen.
      conflict_prevention {String}:
          Specifies whether conflict prevention will be enabled for the input
          LRS. Conflict prevention is only available when editing or performing
          geoprocessing on branch versioned data that is published as a feature
          service.

          * AS_IS-The current conflict prevention setting will be used. This is
          the default.

          * ENABLE-Conflict prevention will be enabled for the input LRS.

          * DISABLE-Conflict prevention will be disabled for the input LRS."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyLRS_locref(*gp_fixargs((in_workspace, current_lrs_name, new_lrs_name, centerline_feature_class, centerline_centerline_id_field, centerline_sequence_table, centerline_sequence_centerline_id_field, centerline_sequence_route_id_field, centerline_sequence_from_date_field, centerline_sequence_to_date_field, centerline_sequence_network_id_field, calibration_point_feature_class, calibration_point_measure_field, calibration_point_from_date_field, calibration_point_to_date_field, calibration_point_route_id_field, calibration_point_network_id_field, redline_feature_class, redline_from_measure_field, redline_to_measure_field, redline_route_id_field, redline_route_name_field, redline_effective_date_field, redline_activity_type_field, redline_network_id_field, conflict_prevention), True)))
        return retval
    except Exception as e:
        raise e


# Configuration\LRS Event toolset
@gptooldoc('CreateLRSEvent_locref', None)
def CreateLRSEvent(parent_network=None, event_name=None, geometry_type=None, event_id_field=None, route_id_field=None, from_date_field=None, to_date_field=None, loc_error_field=None, measure_field=None, to_measure_field=None, event_spans_routes=None, to_route_id_field=None, store_route_name=None, route_name_field=None, to_route_name_field=None):
    """CreateLRSEvent_locref(parent_network, event_name, geometry_type, event_id_field, route_id_field, from_date_field, to_date_field, loc_error_field, measure_field, {to_measure_field}, {event_spans_routes}, {to_route_id_field}, {store_route_name}, {route_name_field}, {to_route_name_field})

        Creates line or point events for an existing LRS Network.

     INPUTS:
      parent_network (Feature Layer):
          The network to which the event is registered.
      event_name (String):
          The event to be registered.
      geometry_type (String):
          The geometry type of the output event.

          * POINT-The geometry type of the event is Point. This is the default.

          * LINE-The geometry type of the event is Polyline.
      event_id_field (String):
          The event ID field available in the event feature class.
      route_id_field (String):
          Name of the route ID field if it is a point event that does not span
          routes, or from route ID field if the event_spans_routes parameter is
          set to SPANS_ROUTES.
      from_date_field (String):
          The from date field available in the event feature class.
      to_date_field (String):
          The to date field available in the event feature class.
      loc_error_field (String):
          The location error field available in the event feature class.
      measure_field (String):
          Name of the measure field if it is a point event or from measure field
          if it is a line event.
      to_measure_field {String}:
          Name of the to measure field. Required only for Line events.
      event_spans_routes {Boolean}:
          Specifies whether the event records spans routes.

          * SPANS_ROUTES-The event records span routes.

          * NO_SPANS_ROUTES-The event records do not span routes. This is the
          default.
      to_route_id_field {String}:
          Name of the to route ID field. Required only if the geometry_type
          parameter is set to LINE and the event_span_routes parameter is set to
          SPANS_ROUTES.
      store_route_name {Boolean}:
          Specifies whether the route name should be stored with the event
          records.

          * STORE_ROUTE_NAME-Stores the route name with the event records.

          * NO_STORE_ROUTE_NAME-Does not store the route name with the event
          records. This is the default.
      route_name_field {String}:
          The route name field if it is a point event that does not span routes,
          or the from route name field if it is a line event that spans routes.
          Required if STORE_ROUTE_NAME is set.
      to_route_name_field {String}:
          The to route name field for line events that span routes. Required if
          STORE_ROUTE_NAME is set."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSEvent_locref(*gp_fixargs((parent_network, event_name, geometry_type, event_id_field, route_id_field, from_date_field, to_date_field, loc_error_field, measure_field, to_measure_field, event_spans_routes, to_route_id_field, store_route_name, route_name_field, to_route_name_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateLRSEventFromExistingDataset_locref', None)
def CreateLRSEventFromExistingDataset(parent_network=None, in_feature_class=None, event_id_field=None, route_id_field=None, from_date_field=None, to_date_field=None, loc_error_field=None, measure_field=None, to_measure_field=None, event_spans_routes=None, to_route_id_field=None, store_route_name=None, route_name_field=None, to_route_name_field=None):
    """CreateLRSEventFromExistingDataset_locref(parent_network, in_feature_class, event_id_field, route_id_field, from_date_field, to_date_field, loc_error_field, measure_field, {to_measure_field}, {event_spans_routes}, {to_route_id_field}, {store_route_name}, {route_name_field}, {to_route_name_field})

        Registers an existing feature class as an LRS event.

     INPUTS:
      parent_network (Feature Layer):
          The network to which the event will be registered.
      in_feature_class (Feature Layer):
          The event to be registered.
      event_id_field (Field):
          The event ID field in the event feature class.
      route_id_field (Field):
          The route ID field if the feature class is a point event or the from
          route ID field if the feature class is a line event and
          event_spans_routes is set to SPANS_ROUTES.
      from_date_field (Field):
          The from date field in the event feature class.
      to_date_field (Field):
          The to date field in the event feature class.
      loc_error_field (Field):
          The location error field in the event feature class.
      measure_field (Field):
          The measure field if the feature class is a point event or the from
          measure field if the feature class is a line event.
      to_measure_field {Field}:
          The to measure field in the event feature class. This parameter is
          required for line events.
      event_spans_routes {Boolean}:
          Specifies whether the event records will span routes.

          * NO_SPANS_ROUTES-The event records will not span routes. This is the
          default.

          * SPANS_ROUTES-The event records will span routes.
      to_route_id_field {Field}:
          The to route ID field for events that span routes. This parameter is
          required if the in_feature class parameter geometry type is polyline
          and event_spans_routes is set to SPANS_ROUTES.
      store_route_name {Boolean}:
          Specifies whether the route name will be stored with the event
          records.

          * NO_STORE_ROUTE_NAME-The route name will not be stored with the
          event records. This is the default.

          * STORE_ROUTE_NAME-The route name will be stored with the event
          records.
      route_name_field {Field}:
          The route name field if the feature class is a point event that
          doesn't span routes or the from route name field if the feature class
          is a line event that spans routes. This parameter is required if
          store_route_name is set to STORE_ROUTE_NAME.
      to_route_name_field {Field}:
          The to route name field for line events that span routes. This
          parameter is required if store_route_name is set to STORE_ROUTE_NAME."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSEventFromExistingDataset_locref(*gp_fixargs((parent_network, in_feature_class, event_id_field, route_id_field, from_date_field, to_date_field, loc_error_field, measure_field, to_measure_field, event_spans_routes, to_route_id_field, store_route_name, route_name_field, to_route_name_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DisableDerivedMeasureFields_locref', None)
def DisableDerivedMeasureFields(in_feature_class=None):
    """DisableDerivedMeasureFields_locref(in_feature_class)

        Disables fields that store the derived network route ID, route name,
        and measure fields.This tool doesn't delete the derived measure
        fields; it only removes
        the derived measure fields' information from the Lrs_Metadata table.

     INPUTS:
      in_feature_class (Feature Layer):
          An existing event feature class or feature layer that is registered to
          an LRS."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DisableDerivedMeasureFields_locref(*gp_fixargs((in_feature_class,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DisableReferentFields_locref', None)
def DisableReferentFields(in_feature_class=None):
    """DisableReferentFields_locref(in_feature_class)

        Disables referent fields for an existing linear referencing system
        (LRS) event feature class or feature layer. It does not delete the
        referent columns; it removes the referent column information from the
        Lrs_Metadata table.

     INPUTS:
      in_feature_class (Feature Layer):
          The input feature class or feature layer for the LRS event."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DisableReferentFields_locref(*gp_fixargs((in_feature_class,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnableDerivedMeasureFields_locref', None)
def EnableDerivedMeasureFields(in_feature_class=None, derived_route_id_field=None, derived_route_name_field=None, derived_from_measure_field=None, derived_to_measure_field=None):
    """EnableDerivedMeasureFields_locref(in_feature_class, {derived_route_id_field}, {derived_route_name_field}, {derived_from_measure_field}, {derived_to_measure_field})

        Enables fields to store the derived route ID, derived route name, and
        derived measure fields for the specified LRS event feature class.

     INPUTS:
      in_feature_class (Feature Layer):
          An existing event feature class or feature layer that is registered to
          an LRS.
      derived_route_id_field {Field}:
          The derived route ID field.
      derived_route_name_field {Field}:
          The derived route name field.
      derived_from_measure_field {Field}:
          The derived from measure field.
      derived_to_measure_field {Field}:
          The derived to measure field."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableDerivedMeasureFields_locref(*gp_fixargs((in_feature_class, derived_route_id_field, derived_route_name_field, derived_from_measure_field, derived_to_measure_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnableReferentFields_locref', None)
def EnableReferentFields(in_feature_class=None, from_referent_method_field=None, from_referent_location_field=None, from_referent_offset_field=None, to_referent_method_field=None, to_referent_location_field=None, to_referent_offset_field=None, offset_units=None):
    """EnableReferentFields_locref(in_feature_class, {from_referent_method_field}, {from_referent_location_field}, {from_referent_offset_field}, {to_referent_method_field}, {to_referent_location_field}, {to_referent_offset_field}, {offset_units})

        Enables or modifies the referent fields so that you can manage
        referent information for the registered LRS event.

     INPUTS:
      in_feature_class (Feature Layer):
          The feature class that will be used for the LRS event.
      from_referent_method_field {Field}:
          The From referent method field.
      from_referent_location_field {Field}:
          The From referent location field.
      from_referent_offset_field {Field}:
          The From referent offset field.
      to_referent_method_field {Field}:
          The To referent method field.
      to_referent_location_field {Field}:
          The To referent location field.
      to_referent_offset_field {Field}:
          The To referent offset field.
      offset_units {String}:
          Specifies the offset units to be used. The default is feet.

          * CENTIMETERS-Centimeters is the offset unit.

          * DECIMETERS-Decimeters is the offset unit.

          * FEET-Feet is the offset unit.

          * INCHES-Inches is the offset unit.

          * KILOMETERS-Kilometers is the offset unit.

          * METERS-Meters is the offset unit.

          * MILES-Miles is the offset unit.

          * MILLIMETERS-Millimeters is the offset unit.

          * YARDS-Yards is the offset unit."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableReferentFields_locref(*gp_fixargs((in_feature_class, from_referent_method_field, from_referent_location_field, from_referent_offset_field, to_referent_method_field, to_referent_location_field, to_referent_offset_field, offset_units), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyEventBehaviorRules_locref', None)
def ModifyEventBehaviorRules(in_feature_class=None, calibrate_rule=None, retire_rule=None, extend_rule=None, reassign_rule=None, realign_rule=None):
    """ModifyEventBehaviorRules_locref(in_feature_class, {calibrate_rule}, {retire_rule}, {extend_rule}, {reassign_rule}, {realign_rule})

        Modifies event behavior rules for the registered event layer or
        feature class.

     INPUTS:
      in_feature_class (Feature Layer):
          The event feature class.
      calibrate_rule {String}:
          Specifies the event behavior rule defined for the calibrate activity.

          * STAY_PUT-The geographic location of the event is preserved; measures
          may change. This is the default.

          * RETIRE-Both measure and geographic location are preserved; the event
          is retired.

          * MOVE-The measures of the event are preserved; the geographic
          location may change.
      retire_rule {String}:
          Specifies the event behavior rule defined for the retire activity.

          * STAY_PUT-The geographic location of the event is preserved; measures
          may change. This is the default.

          * RETIRE-Both measure and geographic location are preserved; the event
          is retired.

          * MOVE-The measures of the event are preserved; the geographic
          location may change.
      extend_rule {String}:
          Specifies the event behavior rule defined for the extend activity.

          * STAY_PUT-The geographic location of the event is preserved; measures
          may change. This is the default.

          * RETIRE-Both measure and geographic location are preserved; the event
          is retired.

          * MOVE-The measures of the event are preserved; the geographic
          location may change.
      reassign_rule {String}:
          Specifies the event behavior rule defined for the reassign activity.

          * STAY_PUT-The geographic location of the event is preserved; measures
          may change. This is the default.

          * RETIRE-Both measure and geographic location are preserved; the event
          is retired.

          * MOVE-The measures of the event are preserved; the geographic
          location may change.

          * SNAP-The geographic location of an event is preserved by snapping
          the event to a concurrent route; measures may change.
      realign_rule {String}:
          Specifies the event behavior rule defined for the realign activity.

          * STAY_PUT-The geographic location of the event is preserved; measures
          may change. This is the default.

          * RETIRE-Both measure and geographic location are preserved; the event
          is retired.

          * MOVE-The measures of the event are preserved; the geographic
          location may change."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyEventBehaviorRules_locref(*gp_fixargs((in_feature_class, calibrate_rule, retire_rule, extend_rule, reassign_rule, realign_rule), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyLRSEvent_locref', None)
def ModifyLRSEvent(in_feature_class=None, event_id_field=None, route_id_field=None, from_date_field=None, to_date_field=None, loc_error_field=None, measure_field=None, to_measure_field=None, event_spans_routes=None, to_route_id_field=None, store_route_name=None, route_name_field=None, to_route_name_field=None):
    """ModifyLRSEvent_locref(in_feature_class, {event_id_field}, {route_id_field}, {from_date_field}, {to_date_field}, {loc_error_field}, {measure_field}, {to_measure_field}, {event_spans_routes}, {to_route_id_field}, {store_route_name}, {route_name_field}, {to_route_name_field})

        Modifies properties of a linear referencing system (LRS) event.

     INPUTS:
      in_feature_class (Feature Layer):
          The input feature class or feature layer for the event.
      event_id_field {Field}:
          Name of the event ID field.
      route_id_field {Field}:
          Name of the route ID field.
      from_date_field {Field}:
          Name of the from date field.
      to_date_field {Field}:
          Name of the to date field.
      loc_error_field {Field}:
          Name of the location error field.
      measure_field {Field}:
          Name of the measure field if it is a point event or from measure field
          if it is a line event.
      to_measure_field {Field}:
          Name of the to measure field. Required only for line events.
      event_spans_routes {String}:
          Determines if the event records will span routes.

          * AS_IS-No change to the property. This is the default.

          * NO_SPANS_ROUTES-The event records do not span routes. Applicable
          only for line events.

          * SPANS_ROUTES-The event records may span routes. Applicable only for
          line events.
      to_route_id_field {Field}:
          Name of the to route ID field. Required only if it is a line event and
          it spans routes.
      store_route_name {String}:
          Determines if the event records will store the route name.

          * AS_IS-No change to the property. This is the default.

          * STORE_ROUTE_NAME-Stores the route name with the event records.

          * NO_STORE_ROUTE_NAME-Does not store the route name with the event
          records.
      route_name_field {Field}:
          The route name field if it is a point event that does not span routes,
          or the from route name field if it is a line event that spans routes.
          Required if STORE_ROUTE_NAME is set.
      to_route_name_field {Field}:
          Name of the to route name field. Required if it is a line event, and
          store_route_name and SPANS_ROUTES are set."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyLRSEvent_locref(*gp_fixargs((in_feature_class, event_id_field, route_id_field, from_date_field, to_date_field, loc_error_field, measure_field, to_measure_field, event_spans_routes, to_route_id_field, store_route_name, route_name_field, to_route_name_field), True)))
        return retval
    except Exception as e:
        raise e


# Configuration\LRS Intersection toolset
@gptooldoc('CreateLRSIntersection_locref', None)
def CreateLRSIntersection(parent_network=None, network_description_field=None, intersection_feature_class_name=None, intersecting_layers=None, consider_z=None, z_tolerance=None):
    """CreateLRSIntersection_locref(parent_network, network_description_field, intersection_feature_class_name, intersecting_layers;intersecting_layers..., {consider_z}, {z_tolerance})

        Creates an intersection feature class for an existing LRS Network.The
        output of this tool is an empty feature class with fields that
        conform to the LRS data model.Run the Generate Intersections tool to
        generate intersection points
        after using this tool.

     INPUTS:
      parent_network (Feature Layer):
          The network to which the intersection will be registered.
      network_description_field (Field):
          The field in the network layer that will be used to name the
          intersections with other intersecting layers.
      intersection_feature_class_name (String):
          The name of the new intersection point feature class.
      intersecting_layers (Value Table):
          The feature class that intersects the LRS Network and contains the
          following information:

          * Intersection Layer-The feature class that intersects the LRS
          Network.

          * ID Field-The field in the intersecting layer used to uniquely
          identify the feature that intersects the network.

          * Description Field-The field that provides the description, such as
          town or county name, of the intersecting feature.

          * Name Separator-The name separator for the intersection, such as AND,
          INTERSECT, +, or |.
      consider_z {Boolean}:
          Specifies whether z-values will be used when generating intersections.

          * CONSIDER_Z-Z-values will be used during generation of intersections.

          * DO_NOT_CONSIDER_Z-Z-values will not be used during generation of
          intersections. This is the default.
      z_tolerance {Double}:
          The z-tolerance used to generate intersections."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSIntersection_locref(*gp_fixargs((parent_network, network_description_field, intersection_feature_class_name, intersecting_layers, consider_z, z_tolerance), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateLRSIntersectionFromExistingDataset_locref', None)
def CreateLRSIntersectionFromExistingDataset(parent_network=None, network_description_field=None, in_feature_class=None, intersection_id_field=None, intersection_name_field=None, route_id_field=None, feature_id_field=None, feature_class_name_field=None, from_date_field=None, to_date_field=None, intersecting_layers=None, consider_z=None, z_tolerance=None, measure_field=None):
    """CreateLRSIntersectionFromExistingDataset_locref(parent_network, network_description_field, in_feature_class, intersection_id_field, intersection_name_field, route_id_field, feature_id_field, feature_class_name_field, from_date_field, to_date_field, intersecting_layers;intersecting_layers..., {consider_z}, {z_tolerance}, {measure_field})

        Registers an existing intersection feature class as an intersection.

     INPUTS:
      parent_network (Feature Layer):
          The network to which the intersection will be registered.
      network_description_field (Field):
          The field in the network layer that will be used to name the
          intersections with other intersecting layers.
      in_feature_class (Feature Layer):
          The input point feature class to be registered.
      intersection_id_field (Field):
          The ID field in the Intersection Feature Class. The field must have a
          unique ID for each intersection for a time slice.
      intersection_name_field (Field):
          The field in the Intersection Feature Class that is a concatenated
          field showing the descriptors for the route and the intersecting
          feature.
      route_id_field (Field):
          The field in the Intersection Feature Class that contains the route ID
          for the LRS Network.
      feature_id_field (Field):
          The field in the Intersection Feature Class that contains the ID for
          the intersecting feature.
      feature_class_name_field (Field):
          The field in the Intersection Feature Class that contains the name of
          the feature class that participated in the intersection.
      from_date_field (Field):
          The from date field in the Intersection Feature Class.
      to_date_field (Field):
          The to date field in the Intersection Feature Class.
      intersecting_layers (Value Table):
          The feature class that intersects the LRS Network and contains the
          following information:

          * Intersection Layer-The feature class that intersects the LRS
          Network.

          * ID Field-The field in the intersecting layer used to uniquely
          identify the feature that intersects the network.

          * Description Field-The field that provides the description, such as
          town or county name, of the intersecting feature.

          * Name Separator-The name separator for the intersection, such as AND,
          INTERSECT, +, or |.
      consider_z {Boolean}:
          Specifies whether z-values will be used when generating intersections.

          * CONSIDER_Z-Z-values will be used during generation of intersections.

          * DO_NOT_CONSIDER_Z-Z-values will not be used during generation of
          intersections. This is the default.
      z_tolerance {Double}:
          The z-tolerance used to generate intersections.
      measure_field {Field}:
          The measure on the base route at the point of intersection."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSIntersectionFromExistingDataset_locref(*gp_fixargs((parent_network, network_description_field, in_feature_class, intersection_id_field, intersection_name_field, route_id_field, feature_id_field, feature_class_name_field, from_date_field, to_date_field, intersecting_layers, consider_z, z_tolerance, measure_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyLRSIntersection_locref', None)
def ModifyLRSIntersection(in_feature_class=None, intersection_id_field=None, intersection_name_field=None, route_id_field=None, feature_id_field=None, feature_class_name_field=None, from_date_field=None, to_date_field=None, intersecting_layers=None, measure_field=None):
    """ModifyLRSIntersection_locref(in_feature_class, {intersection_id_field}, {intersection_name_field}, {route_id_field}, {feature_id_field}, {feature_class_name_field}, {from_date_field}, {to_date_field}, {intersecting_layers;intersecting_layers...}, {measure_field})

        Modifies the properties of an intersection feature class, such as
        fields and intersecting layers, that compose the intersection feature
        class and can be added or removed.

     INPUTS:
      in_feature_class (Feature Layer):
          The input LRS intersection feature layer. This feature class cannot be
          a service.
      intersection_id_field {Field}:
          The field in the Intersection Feature Class to use as the intersection
          unique ID field.
      intersection_name_field {Field}:
          The concatenated field in the Intersection Feature Class that contains
          the descriptors for the route and the intersecting feature.
      route_id_field {Field}:
          The field in the Intersection Feature Class that contains the unique
          route ID.
      feature_id_field {Field}:
          The field in the Intersection Feature Class that contains the ID of
          the intersecting feature.
      feature_class_name_field {Field}:
          The field in the Intersection Feature Class that contains the name of
          the feature class that participated in the intersection.
      from_date_field {Field}:
          The field in the Intersection Feature Class that contains the from
          date of the route.
      to_date_field {Field}:
          The field in the Intersection Feature Class that contains the to date
          of the route.
      intersecting_layers {Value Table}:
          The Intersection Feature Class fields that compose the intersecting
          layer.

          * Intersection Layer-The feature class that intersects the LRS
          Network.

          * ID Field-The field in the intersecting layer used to uniquely
          identify the feature that intersects the network.

          * Description Field-The field that provides the description, such as
          town or county name, of the intersecting feature.

          * Name Separator-The name separator for the intersection, such as AND,
          INTERSECT, +, or |.
      measure_field {Field}:
          The field in the Intersection Feature Class that contains the measure
          on the base route at the point of intersection."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyLRSIntersection_locref(*gp_fixargs((in_feature_class, intersection_id_field, intersection_name_field, route_id_field, feature_id_field, feature_class_name_field, from_date_field, to_date_field, intersecting_layers, measure_field), True)))
        return retval
    except Exception as e:
        raise e


# Configuration\LRS Network toolset
@gptooldoc('ConfigureLookupTable_locref', None)
def ConfigureLookupTable(in_feature_class=None, lookup_table=None, field_applied_to=None, lookup_key=None, lookup_display=None, allow_any_lookup_value=None):
    """ConfigureLookupTable_locref(in_feature_class, lookup_table, field_applied_to, lookup_key, {lookup_display}, {allow_any_lookup_value})

        Configures a lookup table for one or more fields used in a multifield
        route ID.This tool can be run after Create LRS Network From Existing
        Dataset or
        Modify LRS Network for a multifield route ID.A lookup table is an
        alternative to using coded value domains when a
        field that makes up a multifield route ID has several hundred or
        thousands of potential values, for example, a list of street names or
        a Geographic Names Information System (GNIS) code. The lookup table is
        used primarily when creating a route.

     INPUTS:
      in_feature_class (Feature Layer):
          The input LRS Network feature class in which the lookup table will be
          configured. The network must have a multifield route ID.
      lookup_table (Table View):
          A table that contains a list of street names and their corresponding
          GNIS codes. It can be a stand-alone table or reside in an SDE.
      field_applied_to (String):
          The route ID field in the LRS Network in which the lookup_table will
          be configured.
      lookup_key (String):
          The key field in the lookup_table.
      lookup_display {String}:
          The lookup_table description field. This field appears in the text box
          for the multifield route ID.
      allow_any_lookup_value {Boolean}:
          Specifies whether a value that is not in the lookup table can be
          added. The lookup_display parameter cannot be configured when this
          option is checked.

          * DO_NOT_ALLOW_ANY_VALUE-Allow a value to be configured when one is
          not present in the table.

          * ALLOW_ANY_VALUE-Don't allow a lookup display value to be configured.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConfigureLookupTable_locref(*gp_fixargs((in_feature_class, lookup_table, field_applied_to, lookup_key, lookup_display, allow_any_lookup_value), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateLRSNetwork_locref', None)
def CreateLRSNetwork(in_path=None, lrs_name=None, network_name=None, route_id_field=None, route_name_field=None, from_date_field=None, to_date_field=None, derive_from_line_network=None, line_network_name=None, include_fields_to_support_lines=None, line_id_field=None, line_name_field=None, line_order_field=None, measure_unit=None):
    """CreateLRSNetwork_locref(in_path, lrs_name, network_name, route_id_field, route_name_field, from_date_field, to_date_field, {derive_from_line_network}, {line_network_name}, {include_fields_to_support_lines}, {line_id_field}, {line_name_field}, {line_order_field}, {measure_unit})

        Creates an LRS Network in an ArcGIS Location Referencing linear
        referencing system (LRS).

     INPUTS:
      in_path (Workspace / Feature Dataset):
          The input workspace that will contain the new LRS Network. This
          workspace must be a geodatabase that contains a Location Referencing
          LRS. In addition to the top level of a geodatabase, a feature dataset
          is also supported as a valid path.
      lrs_name (String):
          The LRS to which the new LRS Network will be registered. The LRS must
          reside in the same geodatabase as the in_path.
      network_name (String):
          The name of the LRS Network that will be created, as well as the name
          of the feature class that will be created and registered with the LRS
          Network. The LRS Network name must be 26 or fewer characters and
          cannot contain special characters other than underscores.
      route_id_field (String):
          The field in the output feature class that will be mapped as the LRS
          Network route ID. The field type is derived from the RouteId field of
          the centerline sequence table and must be either string or GUID.
      route_name_field (String):
          A string field in the output feature class that will be mapped as the
          LRS Network route name.
      from_date_field (String):
          A date field in the output feature class that will be mapped as the
          LRS Network from date.
      to_date_field (String):
          A date field in the output feature class that will be mapped as the
          LRS Network to date.
      derive_from_line_network {Boolean}:
          Specifies whether the network will be configured as an LRS derived
          network.

          * DERIVE-The output will be an LRS derived network and a feature
          class to support the LRS derived network. The line_network_name
          parameter must also be provided.

          * DO_NOT_DERIVE-The output will not be an LRS derived network. This is
          the default.
      line_network_name {String}:
          The name of the LRS line network to which the output LRS derived
          network will be registered. The input LRS line network must reside in
          the same geodatabase workspace as the line_network_name. This
          parameter is only used if the derive_from_line_network parameter is
          set to DERIVE.
      include_fields_to_support_lines {Boolean}:
          Specifies whether fields that support lines will be added.

          * INCLUDE-The output will be an LRS line network, and the output
          feature class will include fields that support lines. The
          line_id_field, line_name_field, and line_order_field parameters must
          also be provided.

          * DO_NOT_INCLUDE-The output will not be an LRS line network. This is
          the default.
      line_id_field {String}:
          The field in the output feature class that will be mapped as the LRS
          Network line ID. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE. The field
          type is derived from the RouteId field of the centerline sequence
          table and will either be a string of exactly 38 characters or a GUID
          field type.
      line_name_field {String}:
          A string field in the output feature class that will be mapped as the
          LRS Network line name. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE.
      line_order_field {String}:
          The field in the output feature class that will be mapped as the LRS
          Network line order. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE. This will
          be a long integer field type.
      measure_unit {String}:
          Specifies the unit of measure (m-unit) the LRS Network will use.

          * MILES-The unit of measure is miles. This is the default.

          * INCHES-The unit of measure is inches.

          * FEET-The unit of measure is feet.

          * YARDS-The unit of measure is yards.

          * NAUTICAL_MILES-The unit of measure is nautical miles.

          * MILLIMETERS-The unit of measure is millimeters.

          * CENTIMETERS-The unit of measure is centimeters

          * METERS-The unit of measure is meters.

          * KILOMETERS-The unit of measure is kilometers.

          * DECIMETERS-The unit of measure is decimeters."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSNetwork_locref(*gp_fixargs((in_path, lrs_name, network_name, route_id_field, route_name_field, from_date_field, to_date_field, derive_from_line_network, line_network_name, include_fields_to_support_lines, line_id_field, line_name_field, line_order_field, measure_unit), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateLRSNetworkFromExistingDataset_locref', None)
def CreateLRSNetworkFromExistingDataset(in_feature_class=None, lrs_name=None, route_id_field=None, route_name_field=None, from_date_field=None, to_date_field=None, derive_from_line_network=None, line_network_name=None, include_fields_to_support_lines=None, line_id_field=None, line_name_field=None, line_order_field=None, route_id_configuration=None, individual_route_id_fields=None):
    """CreateLRSNetworkFromExistingDataset_locref(in_feature_class, lrs_name, route_id_field, {route_name_field}, from_date_field, to_date_field, {derive_from_line_network}, {line_network_name}, {include_fields_to_support_lines}, {line_id_field}, {line_name_field}, {line_order_field}, {route_id_configuration}, {individual_route_id_fields;individual_route_id_fields...})

        Creates an LRS Network using an existing polyline feature class.

     INPUTS:
      in_feature_class (Feature Layer):
          The input feature class that will be registered as the LRS Network.
          The name of the feature class must be 26 or fewer characters. The
          feature class must reside in a geodatabase that contains a Pipeline
          Referencing LRS. The name of this feature class will be used as the
          name of the LRS Network.
      lrs_name (String):
          The LRS name to which the new LRS Network will be registered. The LRS
          must reside in the same geodatabase as the in_feature_class.
      route_id_field (Field):
          The field in the in_feature_class that will be mapped as the LRS
          Network route ID. This must be a string or GUID field type.
      route_name_field {Field}:
          A string field in the in_feature_class that will be mapped as the LRS
          Network route name.
      from_date_field (Field):
          A date field in the in_feature_class that will be mapped as the LRS
          Network from date.
      to_date_field (Field):
          A date field in the in_feature_class that will be mapped as the LRS
          Network to date.
      derive_from_line_network {Boolean}:
          Specifies whether the network will be configured as an LRS derived
          network.

          * DERIVE-The output of this tool will be an LRS derived network. The
          line_network_name parameter must also be provided.

          * DO_NOT_DERIVE-The output of this tool will not be an LRS derived
          network. This is the default.
      line_network_name {String}:
          The name of the LRS line network to which the output LRS derived
          network will be registered. The input LRS line network must reside in
          the same geodatabase workspace as the in_feature_class. This parameter
          is only used if the derive_from_line_network parameter is set to
          DERIVE.
      include_fields_to_support_lines {Boolean}:
          Specifies whether the network will be configured to support lines.

          * INCLUDE-The output of this tool will be an LRS line network. The
          line_id_field, line_name_field, and line_order_field parameters must
          also be provided.

          * DO_NOT_INCLUDE-The output of this tool will not be an LRS line
          network. This is the default.
      line_id_field {Field}:
          The field in the in_feature_class that will be mapped as the LRS
          Network line ID. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE. This must
          be a string or GUID field type and must match the field type and
          length of the route ID field in the centerline sequence table.
      line_name_field {Field}:
          A string field in the in_feature_class that will be mapped as the LRS
          Network line name. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE.
      line_order_field {Field}:
          An integer field in the in_feature_class that will be mapped as the
          LRS Network line order. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE.
      route_id_configuration {String}:
          Specifies the route ID configuration for the LRS Network.

          * AUTOGENERATED_ROUTE_ID-The route ID field will be an automatically
          generated GUID. The route name can be configured as an LRS field. This
          is the default.

          * SINGLE_FIELD_ROUTE_ID-The route ID field will be a single user-
          generated field. Only nonline networks are supported.

          * MULTI_FIELD_ROUTE_ID-The route ID field will be a user-generated
          field concatenated from more than one field to form the route ID. Only
          nonline networks are supported.
      individual_route_id_fields {Field}:
          The individual fields in the in_feature_class that will be used to
          form the route ID. This parameter is only used if the
          route_id_configuration parameter is set to MULTI_FIELD_ROUTE_ID. The
          fields must be either string or integer field types."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLRSNetworkFromExistingDataset_locref(*gp_fixargs((in_feature_class, lrs_name, route_id_field, route_name_field, from_date_field, to_date_field, derive_from_line_network, line_network_name, include_fields_to_support_lines, line_id_field, line_name_field, line_order_field, route_id_configuration, individual_route_id_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyLRSNetwork_locref', None)
def ModifyLRSNetwork(in_feature_class=None, route_id_field=None, route_name_field=None, from_date_field=None, to_date_field=None, derive_from_line_network=None, line_network_name=None, include_fields_to_support_lines=None, line_id_field=None, line_name_field=None, line_order_field=None, route_id_configuration=None, individual_route_id_fields=None):
    """ModifyLRSNetwork_locref(in_feature_class, {route_id_field}, {route_name_field}, {from_date_field}, {to_date_field}, {derive_from_line_network}, {line_network_name}, {include_fields_to_support_lines}, {line_id_field}, {line_name_field}, {line_order_field}, {route_id_configuration}, {individual_route_id_fields;individual_route_id_fields...})

        Modifies an LRS Network in a Location Referencing linear referencing
        system (LRS).

     INPUTS:
      in_feature_class (Feature Layer):
          The input LRS Network feature class to be modified.
      route_id_field {Field}:
          The field in the input feature class that will be mapped as the LRS
          Network route ID. The field type must match the RouteId field type of
          the Centerline_Sequence table and must either be a string or GUID
          field type.
      route_name_field {Field}:
          A string field in the input feature class that will be mapped as the
          LRS Network route name.
      from_date_field {Field}:
          A date field in the input feature class that will be mapped as the LRS
          Network from date.
      to_date_field {Field}:
          A date field in the input feature class that will be mapped as the LRS
          Network to date.
      derive_from_line_network {String}:
          Determines if the current LRS network will be configured as an LRS
          Derived Network.

          * AS_IS-The current LRS Network derived property will not be changed.
          This is the default.

          * DERIVE-The input LRS Derived Network will be modified to become an
          LRS Derived Network. The line network name parameter must also be
          provided to specify which LRS Network to derive from.

          * DO_NOT_DERIVE-The input LRS Derived Network will be modified to no
          longer be an LRS Derived Network.
      line_network_name {String}:
          The name of the LRS Line Network to which the input LRS Derived
          Network will be registered. The input LRS Line Network must reside in
          the same geodatabase workspace and LRS as the LRS network feature
          class. This parameter is only used if the derive_from_line_network
          parameter is set to DERIVE.
      include_fields_to_support_lines {String}:
          Determines if the current LRS network will be configured to support
          lines.

          * AS_IS-The current LRS Network line support property will not be
          changed. This is the default.

          * INCLUDE-The input LRS Network will be modified to add support for
          lines. The line id field, line name field, and line order field
          parameters must also be provided, and valid fields to map to these
          parameters must exist in the LRS network feature class.

          * DO_NOT_INCLUDE-The input LRS Network will be modified to remove
          support for lines.
      line_id_field {Field}:
          The field in the input feature class that will be mapped as the LRS
          Network line ID. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE. The field
          type must match the RouteId field type of the Centerline_Sequence
          table and must either be a string of exactly 38 characters or a GUID
          field type.
      line_name_field {Field}:
          A string field in the input feature class that will be mapped as the
          LRS Network line name. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE.
      line_order_field {Field}:
          The field in the input feature class that will be mapped as the LRS
          Network line order. This parameter is only used if the
          include_fields_to_support_lines parameter is set to INCLUDE. This must
          be a long integer field type.
      route_id_configuration {String}:
          Determines the route ID configuration for an LRS Network.

          * AS_IS-The current LRS Network route ID configuration will not be
          changed. This is the default.

          * AUTOGENERATED_ROUTE_ID-The route ID field will be an autogenerated
          GUID, and the route name can be configured as an LRS field.

          * SINGLE_FIELD_ROUTE_ID-Supported only for nonline networks.

          * MULTI_FIELD_ROUTE_ID-Supported only for nonline networks. More than
          one field is needed to form the concatenated route ID.
      individual_route_id_fields {Field}:
          The individual fields in the in_feature_class that will be used to
          form the route ID. This parameter is only used if the
          route_id_configuration parameter's MULTI_FIELD_ROUTE_ID option is set.
          The fields must be either string or number integer field types."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyLRSNetwork_locref(*gp_fixargs((in_feature_class, route_id_field, route_name_field, from_date_field, to_date_field, derive_from_line_network, line_network_name, include_fields_to_support_lines, line_id_field, line_name_field, line_order_field, route_id_configuration, individual_route_id_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyNetworkCalibrationRules_locref', None)
def ModifyNetworkCalibrationRules(in_feature_class=None, calibration_rule=None, calibration_offset=None):
    """ModifyNetworkCalibrationRules_locref(in_feature_class, {calibration_rule}, {calibration_offset})

        Modifies the network calibration rules for an LRS Network.When
        creating an LRS Network, you can choose how gapped routes are
        calibrated while creating or editing routes. Using this tool, you can
        configure calibration rules for a network after the LRS Network has
        been created and during the data loading process.Learn more about
        creating and modifying an LRS Network in ArcGIS
        Pipeline Referencing or creating and modifying an LRS Network in
        ArcGIS Roads and Highways. You can use any of the following
        methods to calibrate routes with
        physical gaps:

        * Stepping Increment

        * Adding Increment

        * Euclidean Distance
        Each method will produce a different calibration value for a route
        with physical gaps created using the LRS editing tools. The example
        below shows the calibration of a route created from a centerline with
        physical gaps for each calibration method and calibration of a route
        with retirement between the measure 0.5 and 1 for each calibration
        method.In the retire route scenario, a physical gap is created between
        the
        measures 0.5 and 1. The calibration rules are applied only if a
        physical gap is introduced due to an editing activity and do not
        affect the existing gaps. Note, in the example, the gap between
        measures 2 and 2.5 remains unaffected due to retirement.

     INPUTS:
      in_feature_class (Feature Layer):
          The input LRS Network feature class.
      calibration_rule {String}:
          Specifies the method that will be used to define calibration gap
          measures.

          * AS_IS-The existing defined method in the network will be used while
          changing the calibration offset value.

          * ADDING_EUCLIDEAN_DISTANCE-The Euclidean, or straight-line, distance
          will be calculated and added at each physical gap along an edited
          route.

          * STEPPING_INCREMENT-A value will be defined that will adjust, or
          step, at each physical gap in the route. This is the default.

          * ADDING_INCREMENT-A value will be defined and added to each measure
          of a route at each physical gap, in addition to the total length of
          the from and to measures of the route.
      calibration_offset {Double}:
          The value of the Calibration Rule parameter's Adding Increment or
          Stepping Increment method. The increment value must be numeric and can
          include decimals."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyNetworkCalibrationRules_locref(*gp_fixargs((in_feature_class, calibration_rule, calibration_offset), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ModifyRouteIdPadding_locref', None)
def ModifyRouteIdPadding(in_feature_class=None, route_id_padding=None):
    """ModifyRouteIdPadding_locref(in_feature_class, route_id_padding;route_id_padding...)

        Modifies the padding, null, and length properties for fields that are
        part of a multifield route ID. A route ID is configured with three
        fields: RouteType,
        RouteNumber, and RampNumber. Sample padding and null settings for the
        three fields are shown below.

        * RouteType is a text field with a length of 3. The maximum number of
        characters that will be entered is three; however, some routes may
        have one or two characters entered for this field. A hyphen is used as
        a padding character to the right.

        * RouteNumber is a short field type. The field will have values
        ranging from 0 to 99999; 0 is used as a padding character to the left.

        * RampNumber is a text field with a length of 7; however, some routes
        will not have a value for this field and need to be left blank. An
        underscore is used as a padding character to the left and right.

     INPUTS:
      in_feature_class (Feature Layer):
          The input multifield route ID network layer that contains fields for
          padding, null, and length values that need to be modified.
      route_id_padding (Value Table):
          A table of values that specifies the field to be modified and its
          corresponding padding, null, and length values.

          * Field-The field to be modified.

          * Length-The length value of the field to be modified. The field
          length should be between 1 and the length of the database field.

          * Variable Length-Specifies if the Length value is a variable value or
          a fixed value.

          * Enable Padding-Specifies if the field supports padding.

          * Padding Character-The padding character for the field. The default
          is a space.

          * Padding Location-Specifies where the padding should be
          applied to the field value.

          * Left-Adds the padding characters to the left of the value in the
          field. This is the default.

          * Right-Adds the padding characters to the right of the value in the
          field.

          * Left and Right-Adds the padding characters to the left and right of
          the value in the field.

          * Pad if Null-Specifies if the padding characters are added when the
          field has a null value.

          * Allow Null Values-Specifies if the field supports null values."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ModifyRouteIdPadding_locref(*gp_fixargs((in_feature_class, route_id_padding), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject