# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Parcel Tools"""
__all__ = ['AddParcelType', 'AnalyzeParcelsByLeastSquaresAdjustment',
           'AppendParcels', 'ApplyParcelLeastSquaresAdjustment',
           'BuildParcelFabric', 'CopyParcels', 'CreateParcelFabric',
           'CreateParcelRecords', 'DisableParcelTopology',
           'EnableParcelTopology', 'GenerateParcelFabricLinks',
           'ImportParcelFabricPoints', 'MergeCollinearParcelBoundaries',
           'RemoveParcelType', 'UpgradeArcMapParcelFabric',
           'ValidateParcelFabric']
__alias__ = 'parcel'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('AnalyzeParcelsByLeastSquaresAdjustment_parcel', None)
def AnalyzeParcelsByLeastSquaresAdjustment(in_parcel_fabric=None, analysis_type=None, convergence_tolerance=None):
    """AnalyzeParcelsByLeastSquaresAdjustment_parcel(in_parcel_fabric, analysis_type, {convergence_tolerance})

        Analyzes the parcel fabric measurement network by running a least-
        squares adjustment on the input parcels. A least-squares adjustment is
        a mathematical procedure that uses statistical analysis to estimate
        the most likely coordinates for connected points in a measurement
        network. A least-squares adjustment can be run on the parcel fabric to
        evaluate and improve spatial accuracy of parcel corner point
        locations. Different types of adjustments can be run on the parcel
        fabric
        depending on whether you are evaluating spatial accuracy or improving
        spatial accuracy.

        * Consistency check-Uses a free network adjustment to check
        measurements (dimensions) on input parcel lines for blunders and
        outliers

        * Weighted adjustment-Uses two or more fixed or weighted control
        points to estimate updated coordinates for points on the input parcels

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The input parcel fabric to be analyzed by least-squares adjustment.
      analysis_type (String):
          Specifies the type of least-squares analysis that will be used in the
          adjustment.

          * CONSISTENCY_CHECK-A free-network least-squares adjustment will be
          run to check dimensions on parcel lines for inconsistencies and
          mistakes. Fixed or weighted control points will not be used by the
          adjustment.

          * WEIGHTED_LEAST_SQUARES-A weighted least-squares adjustment will be
          run to compute updated coordinates for parcel points. The parcels
          being adjusted should connect to at least two fixed or weighted
          control points.
      convergence_tolerance {Linear Unit}:
          The tolerance representing the maximum coordinate shift expected after
          iterating the least-squares adjustment. A least-squares adjustment is
          run repeatedly (in iterations) until the solution converges. The
          solution is considered converged when maximum coordinate shift
          encountered becomes less than the specified convergence tolerance. The
          default value is 0.05 meters."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AnalyzeParcelsByLeastSquaresAdjustment_parcel(*gp_fixargs((in_parcel_fabric, analysis_type, convergence_tolerance), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AppendParcels_parcel', None)
def AppendParcels(in_parcel_fabric=None, target_parcel_fabric=None):
    """AppendParcels_parcel(in_parcel_fabric, target_parcel_fabric)

        Appends parcels from an input parcel fabric to a target parcel fabric.
        If the input parcel fabric is a parcel fabric layer with selected
        polygons, the corresponding parcel features will be appended.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The input parcels that will be appended to the target parcel fabric.
          The input parcel fabric can be from a file geodatabase, an enterprise
          geodatabase or a feature service.
      target_parcel_fabric (Parcel Layer):
          The target parcel fabric to which the parcels will be appended. The
          target parcel fabric can be from a file geodatabase or an enterprise
          geodatabase. On an enterprise geodatabase, parcels are appended to the
          default version."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendParcels_parcel(*gp_fixargs((in_parcel_fabric, target_parcel_fabric), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyParcelLeastSquaresAdjustment_parcel', None)
def ApplyParcelLeastSquaresAdjustment(in_parcel_fabric=None, movement_tolerance=None, update_attributes=None):
    """ApplyParcelLeastSquaresAdjustment_parcel(in_parcel_fabric, {movement_tolerance}, {update_attributes})

        Applies the results of a least squares adjustment to parcel fabric
        feature classes. Least squares adjustment results stored in the
        AdjustmentLines and AdjustmentPoints feature classes are applied to
        the corresponding parcel line, connection line, and parcel fabric
        point feature classes.Use the Analyze Parcels By Least Squares
        Adjustment tool to run a
        least-squares adjustment on parcels and store the results in
        adjustment feature classes.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric to be updated.
      movement_tolerance {Linear Unit}:
          The tolerance representing the minimum allowable coordinate shift when
          updating parcel fabric points. If the distance between the adjustment
          point and the parcel fabric point is greater than the specified
          tolerance, the parcel fabric point is updated to the location of the
          adjustment point. The default tolerance is 0.05 meters.
      update_attributes {Boolean}:
          Specifies whether attribute fields in the parcel fabric Points feature
          class will be updated with statistical metadata. The XY Uncertainty,
          Error Ellipse Semi Major, Error Ellipse Semi Minor, and Error Ellipse
          Direction fields will be updated with the values stored in the same
          fields in the AdjustmentPoints feature class.

          * UPDATE_ATTRIBUTES-Attribute fields in the parcel fabric Points
          feature class will be updated with statistical metadata.

          * NO_UPDATE_ATTRIBUTES-Attribute fields will not be updated. This is
          the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyParcelLeastSquaresAdjustment_parcel(*gp_fixargs((in_parcel_fabric, movement_tolerance, update_attributes), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('BuildParcelFabric_parcel', None)
def BuildParcelFabric(in_parcel_fabric=None, extent=None, record_name=None):
    """BuildParcelFabric_parcel(in_parcel_fabric, {extent}, {record_name})

        Builds parcels in a parcel fabric. Parcels can be built from polygons
        or lines. If parcels are built from polygons, the tool creates parcel
        lines and parcel points. If parcels are built from lines, the tool
        creates the missing polygons and points. When building parcels from
        lines, parcel seeds are required. Additionally, the following data
        is updated:

        * Parcel record polygons are updated to match the cumulative geometry
        of all the parcels associated to them.

        * The Parcel Count field on the Records feature class is updated with
        the number of parcels associated to each record.

        * If the COGO Accuracy field on the Records feature class has an
        accuracy value, it will be transferred to the COGO Accuracy field of
        all the lines associated to the record.
        Record polygons are not created or updated when more than 2,000
        parcels are associated to a record.Learn more about building parcels
        from polygons and lines.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric for which to build parcels. The parcel fabric can be
          from a file geodatabase or a feature service.
      extent {Extent}:
          The extent of the dataset to be processed. Only features that fall
          within the specified extent will be processed.

          * MAXOF-The maximum extent of all inputs will be used.

          * MINOF-The minimum area common to all inputs will be used.

          * DISPLAY-The extent is equal to the visible display.

          * Layer name-The extent of the specified layer will be used.

          * Extent object-The extent of the specified object will be used.

          * Space delimited string of coordinates-The extent of the specified
          string will be used. Coordinates are expressed in the order of x-min,
          y-min, x-max, y-max.
      record_name {String}:
          The name of the existing parcel record. Only parcels associated to
          this record will be built."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.BuildParcelFabric_parcel(*gp_fixargs((in_parcel_fabric, extent, record_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CopyParcels_parcel', None)
def CopyParcels(in_parcel_fabric=None, target_database=None, out_dataset_name=None, out_fabric_name=None):
    """CopyParcels_parcel(in_parcel_fabric, target_database, {out_dataset_name}, {out_fabric_name})

        Copies parcels from an input parcel fabric to a new parcel fabric in a
        new feature dataset.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The input parcels that will be copied to a new parcel fabric. The
          input parcel fabric can be from a file geodatabase, an enterprise
          geodatabase connection, or a feature service.
      target_database (Workspace):
          The geodatabase in which the new parcel fabric will be created. The
          geodatabase can be a file or an enterprise geodatabase.
      out_dataset_name {String}:
          The name of the feature dataset that will be created for the new
          parcel fabric.
      out_fabric_name {String}:
          The name of the new parcel fabric."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyParcels_parcel(*gp_fixargs((in_parcel_fabric, target_database, out_dataset_name, out_fabric_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateParcelFabricLinks_parcel', None)
def GenerateParcelFabricLinks(target_parcel_fabric=None, out_links_feature_class=None, out_anchor_points_feature_class=None, from_date=None, to_date=None, min_link_length=None, extent=None):
    """GenerateParcelFabricLinks_parcel(target_parcel_fabric, out_links_feature_class, out_anchor_points_feature_class, from_date, {to_date}, {min_link_length}, {extent})

        Generates displacement links for parcel fabric points that have
        changed locations in a specified time period.Links are stored as lines
        in a line feature class and are drawn from
        the original locations to the current locations of the points. Anchor
        points are created for points that have not changed locations in the
        specified time period and are stored in a point feature class.Parcel
        fabric points can change locations as a result of editing
        actions such as parcel alignment or from least squares adjustments of
        parcels.

     INPUTS:
      target_parcel_fabric (Parcel Layer):
          The parcel fabric that will be used to generate links. The parcel
          fabric must be published as a feature service and the default version
          is used to generate links.
      from_date (Date):
          The date from which to search the parcel fabric for points that have
          changed locations. Links and anchor points will be only be generated
          for points on or after this date.
      to_date {Date}:
          The end date of the time period in which to search the parcel fabric
          for points that have changed locations. Links and anchor points will
          only be generated for points on or before this date. If no To date is
          specified, links and anchor points will be generated for all points on
          or after the specified From Date. If the To Date is specified at a
          future date, links will be generated in the time period between the
          From Date and the current date and time.
      min_link_length {Linear Unit}:
          The minimum length of the generated links. If the link length between
          the current points and their original locations is smaller than the
          specified value, anchor points are created for the original locations
          of the points.
      extent {Extent}:
          The extent of the dataset to be processed. Only features that fall
          within the specified extent will be processed.

          * MAXOF-The maximum extent of all inputs will be used.

          * MINOF-The minimum area common to all inputs will be used.

          * DISPLAY-The extent is equal to the visible display.

          * Layer name-The extent of the specified layer will be used.

          * Extent object-The extent of the specified object will be used.

          * Space delimited string of coordinates-The extent of the specified
          string will be used. Coordinates are expressed in the order of x-min,
          y-min, x-max, y-max.

     OUTPUTS:
      out_links_feature_class (Feature Class):
          The output line feature class that will store the generated links.
      out_anchor_points_feature_class (Feature Class):
          The output point feature class that will store the anchor points."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateParcelFabricLinks_parcel(*gp_fixargs((target_parcel_fabric, out_links_feature_class, out_anchor_points_feature_class, from_date, to_date, min_link_length, extent), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportParcelFabricPoints_parcel', None)
def ImportParcelFabricPoints(source_points=None, target_parcel_fabric=None, match_point_method=None, search_distance=None, update_type=None, record_name=None, match_field=None, conflicts_table=None):
    """ImportParcelFabricPoints_parcel(source_points, target_parcel_fabric, match_point_method, search_distance, update_type, {record_name}, {match_field}, {conflicts_table})

        Imports point data from a source point feature class into the parcel
        fabric points feature class. Parcel fabric points that match or lie
        within a proximity tolerance of the source points will be updated with
        the imported point data. If the source points layer has a selection,
        only the selected point information will be imported.Parcel fabric
        points can be updated in the following ways:

        * Points can be retired and new points can be created with updated
        information from the imported points.

        * Points can be updated with attribute information from the source
        points. The existing parcel fabric points still remain active
        (nonhistoric).
        If the source and target parcel fabric points meet the search
        criteria, and if the source point feature class has z-values, the
        shape x,y,z coordinates of the parcel fabric points are updated. If
        the source point feature class does not have z-values, only the shape
        x,y coordinates of the parcel fabric points are updated and the
        existing z-values remain unchanged. When the shape x,y coordinates of
        parcel fabric points are updated, connected parcel lines and polygons
        are updated to match the new coordinate locations.When points are
        created, they can be optionally assigned to a new or
        existing parcel record.

     INPUTS:
      source_points (Feature Layer):
          The source point feature class that will be used to update points in
          the target parcel fabric.
      target_parcel_fabric (Parcel Layer):
          The target parcel fabric containing the points that will be updated.
          The target parcel fabric can be from a file geodatabase, an enterprise
          geodatabase connected to the default version, or a feature service.
      match_point_method (String):
          Specifies the method that will be used to find parcel fabric points
          that match the source points.

          * PROXIMITY-Parcel fabric points that lie within the proximity
          tolerance of the source points will be matched to the source points
          and updated. This is the default.

          * NAME_AND_PROXIMITY-Parcel fabric points that lie within the
          proximity tolerance and have the same name as the source points will
          be matched to the source points and updated.

          * GLOBALID_AND_PROXIMITY-Parcel fabric points that lie within the
          proximity tolerance and have the same Global ID as the source points
          will be matched to the source points and updated. Global IDs are
          stored in the Global ID field of the parcel fabric points feature
          class and in the specified Global ID field of the source feature
          class.
      search_distance (Linear Unit):
          The distance that will be used to search for parcel fabric points that
          lie within the proximity of source points. If a parcel fabric point is
          found within the search distance of a source point, the points will be
          matched and the parcel fabric point will be updated.
      update_type (String):
          Specifies the type of update that will be applied to parcel fabric
          points that match source points.

          * ALL-The geometry (x,y,z) and matching attribute fields of parcel
          fabric points will be updated. If the geometry of parcel fabric points
          are updated, coincident parcel features are updated as well. This is
          the default.

          * GEOMETRY_XYZ-Only the geometry (x,y,z) of the parcel fabric points
          will be updated. Coincident parcel features will be updated as well.

          * RETIRE_AND_REPLACE-Source points will be imported as new parcel
          fabric points. Any matching parcel fabric points will be retired as
          historic. The Retired By Record field of each matching parcel fabric
          point will be populated with the GlobalID of the record specified in
          the Record Name parameter.
      record_name {String}:
          The name of the record that will be associated with the new imported
          points.If the record already exists in the target parcel fabric, the
          new
          points are associated with the record. If the record does not exist, a
          record will be created. If new points replace existing points, and
          Update Type is set to Retire and replace (update_type =
          RETIRE_AND_REPLACE in Python), the record will be used to retire the
          points as historic.
      match_field {Field}:
          The field that will be used to match source points to parcel fabric
          points when Name and proximity (NAME_AND_PROXIMITY in Python) or
          Global ID and proximity (GLOBALID_AND_PROXIMITY in Python) is used for
          the Match Point Method (match_point_method in Python) parameter. When
          searching by name, the field in the source point feature class should
          be of type Text. When searching by Global ID, the field in the source
          point feature class should be of type GUID.

     OUTPUTS:
      conflicts_table {Table}:
          The path and name of the output table that will store conflicts. If
          more than one parcel fabric point is found within the search tolerance
          of a source point, the object IDs of the source points and parcel
          fabric points will be reported in the conflicts table."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportParcelFabricPoints_parcel(*gp_fixargs((source_points, target_parcel_fabric, match_point_method, search_distance, update_type, record_name, match_field, conflicts_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MergeCollinearParcelBoundaries_parcel', None)
def MergeCollinearParcelBoundaries(in_parcel_boundaries=None, offset_tolerance=None):
    """MergeCollinearParcelBoundaries_parcel(in_parcel_boundaries, offset_tolerance)

        Merges connected collinear parcel lines into a single parcel line.
        Shared parcel fabric points between connected collinear lines are
        deleted and vertices are created in their place.Pairs of connected
        parcel lines are considered collinear if their
        shared parcel fabric points lie within the specified orthogonal offset
        tolerance of the straight lines between the line endpoints.

     INPUTS:
      in_parcel_boundaries (Feature Layer):
          The parcel lines to be merged. Lines can be parcel lines or connection
          lines.
      offset_tolerance (Linear Unit):
          The maximum distance shared parcel points can be offset from their
          connected lines for the lines to be considered collinear. The offset
          is the distance between the shared parcel points and the straight
          lines between the endpoints of the connected parcel lines."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MergeCollinearParcelBoundaries_parcel(*gp_fixargs((in_parcel_boundaries, offset_tolerance), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ValidateParcelFabric_parcel', None)
def ValidateParcelFabric(in_parcel_fabric=None, extent=None):
    """ValidateParcelFabric_parcel(in_parcel_fabric, {extent})

        Validates a parcel fabric against a predefined set of parcel rules,
        geodatabase topology rules, and any additional rules you have added
        for your organization.The parcel fabric uses geodatabase topology
        rules and parcel rules to
        define parcels and model their behavior. Geodatabase topology rules
        define the spatial relationships between parcel features, and parcel
        rules define behavior that is specific to parcel features. You can
        define additional geodatabase topology rules and attribute rules to
        manage and enforce data quality standards in your organization.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric to be validated. The parcel fabric can be from a
          file geodatabase or a feature service.
      extent {Extent}:
          The extent of the dataset to be processed. Only features that fall
          within the specified extent will be processed.

          * MAXOF-The maximum extent of all inputs will be used.

          * MINOF-The minimum area common to all inputs will be used.

          * DISPLAY-The extent is equal to the visible display.

          * Layer name-The extent of the specified layer will be used.

          * Extent object-The extent of the specified object will be used.

          * Space delimited string of coordinates-The extent of the specified
          string will be used. Coordinates are expressed in the order of x-min,
          y-min, x-max, y-max."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ValidateParcelFabric_parcel(*gp_fixargs((in_parcel_fabric, extent), True)))
        return retval
    except Exception as e:
        raise e


# Administration toolset
@gptooldoc('AddParcelType_parcel', None)
def AddParcelType(in_parcel_fabric=None, name=None, administrative_polygon=None):
    """AddParcelType_parcel(in_parcel_fabric, name, {administrative_polygon})

        Adds a parcel type to a parcel fabric. A parcel type is defined by a
        separate polygon and line feature class. Parcel type feature classes
        are controlled by the parcel fabric dataset.Parcels are stored in the
        parcel fabric as parcel types. Examples of
        parcel types are ownership parcels, administrative parcels, and
        subdivision parcels.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric to which the parcel type will be added. The parcel
          fabric can be from a file or and enterprise geodatabase.
      name (String):
          The name of the parcel type. The name will be assigned to the output
          polygon and line feature classes.
      administrative_polygon {Boolean}:
          Administrative boundaries are used for very large parcels such as
          country parcels or state parcels. The parcel type polygon feature
          class will not participate in the parcel fabric topology.

          * ADMINISTRATIVE_POLYGON-The parcel type is used to store
          administrative boundaries. The parcel type polygon feature class will
          not participate in the parcel fabric topology.

          * TOPOLOGY_POLYGON-The parcel type will not store administrative
          boundaries. The parcel type polygon feature class will participate in
          the parcel fabric topology. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddParcelType_parcel(*gp_fixargs((in_parcel_fabric, name, administrative_polygon), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateParcelFabric_parcel', None)
def CreateParcelFabric(target_dataset=None, name=None):
    """CreateParcelFabric_parcel(target_dataset, name)

        Creates a parcel fabric and its associated datasets. The parcel fabric
        is created in a feature dataset that resides in a file or an
        enterprise geodatabase.The parcel fabric is created as a controller
        dataset that controls the
        following datasets:

        * Parcel fabric topology

        * Records feature class

        * Connections feature class

        * Points feature class
        Parcels are added to the parcel fabric as parcel types. Use the Add
        Parcel Type tool to add parcel types to the parcel fabric. The
        Connections, Points and parcel type feature classes participate in the
        parcel fabric topology.

     INPUTS:
      target_dataset (Feature Dataset):
          The feature dataset in which the parcel fabric and related schema will
          be created. The feature dataset can reside in a file or an enterprise
          geodatabase.
      name (String):
          The name of the parcel fabric that will be created. Associated
          datasets will be prefixed with the parcel fabric name."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateParcelFabric_parcel(*gp_fixargs((target_dataset, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateParcelRecords_parcel', None)
def CreateParcelRecords(in_parcel_features=None, record_field=None, record_expression=None, record_name_method=None):
    """CreateParcelRecords_parcel(in_parcel_features, {record_field}, {record_expression}, {record_name_method})

        Creates parcel records for the input parcel fabric features using a
        record name field or an expression.Parcel records are created and
        added to the parcel fabric Records
        feature class. The parcel record polygons will match the cumulative
        geometry of all parcel polygons associated with them.The Records
        feature class stores information about the legal parcel
        record such as the record date and record type. In the parcel fabric,
        parcel features are associated with the record that created and
        retired them (made historic).

     INPUTS:
      in_parcel_features (Feature Layer):
          The input parcel features that will be used to create parcel records.
          The input parcel features can be from a parcel fabric in a file
          geodatabase or an enterprise geodatabase.
      record_field {Field}:
          The attribute field that contains the record names. The attribute
          field must be a text field and must contain parcel record names that
          correspond to their associated parcel features.
      record_expression {Calculator Expression}:
          An Arcade expression that uses fields, string operators, and
          mathematical operators to represent the record names. For example, the
          expression Left($feature.Name,4) extracts the first four characters
          from the parcel name field in the parcel fabric polygon feature class
          to create the record names.
      record_name_method {String}:
          Specifies the method to use to create parcel records.

          * FIELD-Parcel records will be created using record names from a text
          field on the input parcel features. This is the default.

          * EXPRESSION-Parcel records will be created using an Arcade
          expression."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateParcelRecords_parcel(*gp_fixargs((in_parcel_features, record_field, record_expression, record_name_method), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DisableParcelTopology_parcel', None)
def DisableParcelTopology(in_parcel_fabric=None):
    """DisableParcelTopology_parcel(in_parcel_fabric)

        Disables topology on a parcel fabric. System-defined parcel rules and
        topology rules and parcel fabric feature classes will be removed from
        the topology.Disable the parcel fabric topology before operations such
        as adding
        parcel types, adding attribute fields, and batch calculating attribute
        fields.Learn more about the parcel fabric topology.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric for which the topology will be disabled. The input
          parcel fabric can be from a file geodatabase or an enterprise
          geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DisableParcelTopology_parcel(*gp_fixargs((in_parcel_fabric,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnableParcelTopology_parcel', None)
def EnableParcelTopology(in_parcel_fabric=None):
    """EnableParcelTopology_parcel(in_parcel_fabric)

        Enables topology on a parcel fabric. The tool adds the following
        to the parcel topology:

        * System-defined parcel rules and geodatabase topology rules

        * Parcel fabric feature classes
        Once the parcel fabric topology is enabled, the parcel fabric can be
        validated to identify rule errors, and parcels can be built.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric for which the topology will be enabled. The input
          parcel fabric can be from a file geodatabase or an enterprise
          geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableParcelTopology_parcel(*gp_fixargs((in_parcel_fabric,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveParcelType_parcel', None)
def RemoveParcelType(in_parcel_fabric=None, name=None):
    """RemoveParcelType_parcel(in_parcel_fabric, name)

        Removes a parcel type from a parcel fabric.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric from which the parcel type will be removed. The
          parcel fabric can be from a file geodatabase or an enterprise
          geodatabase.
      name (String):
          The name of the parcel type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveParcelType_parcel(*gp_fixargs((in_parcel_fabric, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpgradeArcMapParcelFabric_parcel', None)
def UpgradeArcMapParcelFabric(in_parcel_fabric=None, target_dataset=None, name=None):
    """UpgradeArcMapParcelFabric_parcel(in_parcel_fabric, target_dataset, name)

        Upgrades an ArcMap parcel fabric to an ArcGIS Pro parcel fabric.The
        tool creates a parcel fabric in a feature dataset and transfers
        data from the ArcMap parcel fabric feature classes to the ArcGIS Pro
        parcel fabric feature classes. The existing ArcMap parcel fabric is
        not altered.

     INPUTS:
      in_parcel_fabric (Parcel Fabric Layer for ArcMap):
          The ArcMap parcel fabric that will be upgraded to an ArcGIS Pro parcel
          fabric.
      target_dataset (Feature Dataset):
          The feature dataset that will contain the upgraded ArcGIS Pro parcel
          fabric.
      name (String):
          The name of the upgraded ArcGIS Pro parcel fabric."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpgradeArcMapParcelFabric_parcel(*gp_fixargs((in_parcel_fabric, target_dataset, name), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject